@@ -17,6 +17,10 @@ if python_version_tuple()[0] < "3":
     _float_type = float
     _text_type = unicode
     _binary_type = str
+
+    def _is_file(f):
+        return isinstance(f, file)
+
 else:
     from itertools import zip_longest as izip_longest
     from functools import reduce, partial
@@ -26,9 +30,13 @@ else:
     _text_type = str
     _binary_type = bytes
 
+    import io
+    def _is_file(f):
+        return isinstance(f, io.IOBase)
+
 
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
-__version__ = "0.7.3"
+__version__ = "0.7.4"
 
 
 MIN_PADDING = 2
@@ -111,6 +119,16 @@ def _mediawiki_row_with_attrs(separator, cell_values, colwidths, colaligns):
     return (separator + colsep.join(values_with_attrs)).rstrip()
 
 
+def _html_row_with_attrs(celltag, cell_values, colwidths, colaligns):
+    alignment = { "left":    '',
+                  "right":   ' style="text-align: right;"',
+                  "center":  ' style="text-align: center;"',
+                  "decimal": ' style="text-align: right;"' }
+    values_with_attrs = ["<{0}{1}>{2}</{0}>".format(celltag, alignment.get(a, ''), c)
+                         for c, a in zip(cell_values, colaligns)]
+    return "<tr>" + "".join(values_with_attrs).rstrip() + "</tr>"
+
+
 def _latex_line_begin_tabular(colwidths, colaligns, booktabs=False):
     alignment = { "left": "l", "right": "r", "center": "c", "decimal": "r" }
     tabular_columns_fmt = "".join([alignment.get(a, "l") for a in colaligns])
@@ -154,6 +172,14 @@ _table_formats = {"simple":
                               headerrow=DataRow("|", "|", "|"),
                               datarow=DataRow("|", "|", "|"),
                               padding=1, with_header_hide=None),
+                  "fancy_grid":
+                  TableFormat(lineabove=Line("╒", "═", "╤", "╕"),
+                              linebelowheader=Line("╞", "═", "╪", "╡"),
+                              linebetweenrows=Line("├", "─", "┼", "┤"),
+                              linebelow=Line("╘", "═", "╧", "╛"),
+                              headerrow=DataRow("│", "│", "│"),
+                              datarow=DataRow("│", "│", "│"),
+                              padding=1, with_header_hide=None),
                   "pipe":
                   TableFormat(lineabove=_pipe_line_with_colons,
                               linebelowheader=_pipe_line_with_colons,
@@ -171,6 +197,14 @@ _table_formats = {"simple":
                               headerrow=DataRow("|", "|", "|"),
                               datarow=DataRow("|", "|", "|"),
                               padding=1, with_header_hide=None),
+                  "psql":
+                  TableFormat(lineabove=Line("+", "-", "+", "+"),
+                              linebelowheader=Line("|", "-", "+", "|"),
+                              linebetweenrows=None,
+                              linebelow=Line("+", "-", "+", "+"),
+                              headerrow=DataRow("|", "|", "|"),
+                              datarow=DataRow("|", "|", "|"),
+                              padding=1, with_header_hide=None),
                   "rst":
                   TableFormat(lineabove=Line("", "=", "  ", ""),
                               linebelowheader=Line("", "=", "  ", ""),
@@ -188,6 +222,14 @@ _table_formats = {"simple":
                               headerrow=partial(_mediawiki_row_with_attrs, "!"),
                               datarow=partial(_mediawiki_row_with_attrs, "|"),
                               padding=0, with_header_hide=None),
+                  "html":
+                  TableFormat(lineabove=Line("<table>", "", "", ""),
+                              linebelowheader=None,
+                              linebetweenrows=None,
+                              linebelow=Line("</table>", "", "", ""),
+                              headerrow=partial(_html_row_with_attrs, "th"),
+                              datarow=partial(_html_row_with_attrs, "td"),
+                              padding=0, with_header_hide=None),
                   "latex":
                   TableFormat(lineabove=_latex_line_begin_tabular,
                               linebelowheader=Line("\\hline", "", "", ""),
@@ -400,7 +442,10 @@ def _align_column(strings, alignment, minwidth=0, has_invisible=True):
         strings = [s.strip() for s in strings]
         padfn = _padboth
     elif alignment == "decimal":
-        decimals = [_afterpoint(s) for s in strings]
+        if has_invisible:
+            decimals = [_afterpoint(_strip_invisible(s)) for s in strings]
+        else:
+            decimals = [_afterpoint(s) for s in strings]
         maxdecimals = max(decimals)
         strings = [s + (maxdecimals - decs) * " "
                    for s, decs in zip(strings, decimals)]
@@ -452,7 +497,7 @@ def _column_type(strings, has_invisible=True):
     return reduce(_more_generic, types, int)
 
 
-def _format(val, valtype, floatfmt, missingval=""):
+def _format(val, valtype, floatfmt, missingval="", has_invisible=True):
     """Format a value accoding to its type.
 
     Unicode is supported:
@@ -475,7 +520,13 @@ def _format(val, valtype, floatfmt, missingval=""):
         except TypeError:
             return _text_type(val)
     elif valtype is float:
-        return format(float(val), floatfmt)
+        is_a_colored_number = has_invisible and type(val) in [_text_type, _binary_type]
+        if is_a_colored_number:
+            raw_val = _strip_invisible(val)
+            formatted_val = format(float(raw_val), floatfmt)
+            return val.replace(raw_val, formatted_val)
+        else:
+            return format(float(val), floatfmt)
     else:
         return "{0}".format(val)
 
@@ -725,6 +776,18 @@ def tabulate(tabular_data, headers=[], tablefmt="simple",
     | eggs | 451      |
     +------+----------+
 
+    "fancy_grid" draws a grid using box-drawing characters:
+
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
+    ...                ["strings", "numbers"], "fancy_grid"))
+    ╒═══════════╤═══════════╕
+    │ strings   │   numbers │
+    ╞═══════════╪═══════════╡
+    │ spam      │   41.9999 │
+    ├───────────┼───────────┤
+    │ eggs      │  451      │
+    ╘═══════════╧═══════════╛
+
     "pipe" is like tables in PHP Markdown Extra extension or Pandoc
     pipe_tables:
 
@@ -790,6 +853,16 @@ def tabulate(tabular_data, headers=[], tablefmt="simple",
     | eggs      || align="right"|  451
     |}
 
+    "html" produces HTML markup:
+
+    >>> print(tabulate([["strings", "numbers"], ["spam", 41.9999], ["eggs", "451.0"]],
+    ...                headers="firstrow", tablefmt="html"))
+    <table>
+    <tr><th>strings  </th><th style="text-align: right;">  numbers</th></tr>
+    <tr><td>spam     </td><td style="text-align: right;">  41.9999</td></tr>
+    <tr><td>eggs     </td><td style="text-align: right;"> 451     </td></tr>
+    </table>
+
     "latex" produces a tabular environment of LaTeX document markup:
 
     >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], tablefmt="latex"))
@@ -828,7 +901,7 @@ def tabulate(tabular_data, headers=[], tablefmt="simple",
     # format rows and columns, convert numeric values to strings
     cols = list(zip(*list_of_lists))
     coltypes = list(map(_column_type, cols))
-    cols = [[_format(v, ct, floatfmt, missingval) for v in c]
+    cols = [[_format(v, ct, floatfmt, missingval, has_invisible) for v in c]
              for c,ct in zip(cols, coltypes)]
 
     # align columns
@@ -926,3 +999,78 @@ def _format_table(fmt, headers, rows, colwidths, colaligns):
         lines.append(_build_line(padded_widths, colaligns, fmt.linebelow))
 
     return "\n".join(lines)
+
+
+def _main():
+    """\
+    Usage: tabulate [options] [FILE ...]
+
+    Pretty-print tabular data.
+    See also https://bitbucket.org/astanin/python-tabulate
+
+    FILE                      a filename of the file with tabular data;
+                              if "-" or missing, read data from stdin.
+
+    Options:
+
+    -h, --help                show this message
+    -1, --header              use the first row of data as a table header
+    -o FILE, --output FILE    print table to FILE (default: stdout)
+    -s REGEXP, --sep REGEXP   use a custom column separator (default: whitespace)
+    -f FMT, --format FMT      set output table format; supported formats:
+                              plain, simple, grid, fancy_grid, pipe, orgtbl,
+                              rst, mediawiki, html, latex, latex_booktabs, tsv
+                              (default: simple)
+    """
+    import getopt
+    import sys
+    import textwrap
+    usage = textwrap.dedent(_main.__doc__)
+    try:
+        opts, args = getopt.getopt(sys.argv[1:],
+                                   "h1o:s:f:",
+                                   ["help", "header", "output", "sep=", "format="])
+    except getopt.GetoptError as e:
+        print(e)
+        print(usage)
+        sys.exit(2)
+    headers = []
+    tablefmt = "simple"
+    sep = r"\s+"
+    outfile = "-"
+    for opt, value in opts:
+        if opt in ["-1", "--header"]:
+            headers = "firstrow"
+        elif opt in ["-o", "--output"]:
+            outfile = value
+        elif opt in ["-f", "--format"]:
+            if value not in tabulate_formats:
+                print("%s is not a supported table format" % value)
+                print(usage)
+                sys.exit(3)
+            tablefmt = value
+        elif opt in ["-s", "--sep"]:
+            sep = value
+        elif opt in ["-h", "--help"]:
+            print(usage)
+            sys.exit(0)
+    files = [sys.stdin] if not args else args
+    with (sys.stdout if outfile == "-" else open(outfile, "w")) as out:
+        for f in files:
+            if f == "-":
+                f = sys.stdin
+            if _is_file(f):
+                _pprint_file(f, headers=headers, tablefmt=tablefmt, sep=sep, file=out)
+            else:
+                with open(f) as fobj:
+                    _pprint_file(fobj, headers=headers, tablefmt=tablefmt, sep=sep, file=out)
+
+
+def _pprint_file(fobject, headers, tablefmt, sep, file):
+    rows = fobject.readlines()
+    table = [re.split(sep, r.rstrip()) for r in rows]
+    print(tabulate(table, headers, tablefmt), file=file)
+
+
+if __name__ == "__main__":
+    _main()
