@@ -5,7 +5,7 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 from tabulate import tabulate
-from common import assert_equal
+from common import assert_equal, assert_in
 
 
 def test_ansi_color_in_table_cells():
@@ -169,3 +169,40 @@ def test_latex_escape_special_chars():
         r'\end{tabular}'])
     result = tabulate([["&%^_$#{}<>~"]], ["foo^bar"], tablefmt="latex")
     assert_equal(result, expected)
+
+
+def test_isconvertible_on_set_values():
+    "Regression: don't fail with TypeError on set values (issue #35)"
+    expected_py2 = "\n".join([
+        'a    b',
+        '---  -------',
+        'Foo  set([])',])
+    expected_py3 = "\n".join([
+        'a    b',
+        '---  -----',
+        'Foo  set()',])
+    result = tabulate([["Foo",set()]], headers=["a","b"])
+    assert_in(result, [expected_py2, expected_py3])
+
+
+def test_ansi_color_for_decimal_numbers():
+    "Regression: ANSI colors for decimal numbers (issue #36)"
+    table = [["Magenta", "\033[95m" + "1.1" + "\033[0m"]]
+    expected = "\n".join([
+        '-------  ---',
+        'Magenta  \x1b[95m1.1\x1b[0m',
+        '-------  ---'])
+    result = tabulate(table)
+    assert_equal(result, expected)
+
+
+def test_alignment_of_decimal_numbers_with_ansi_color():
+    "Regression: alignment for decimal numbers with ANSI color (issue #42)"
+    v1 = "\033[95m" + "12.34" + "\033[0m"
+    v2 = "\033[95m" + "1.23456" + "\033[0m"
+    table = [[v1], [v2]]
+    expected = "\n".join([
+        '\x1b[95m12.34\x1b[0m',
+        ' \x1b[95m1.23456\x1b[0m'])
+    result = tabulate(table, tablefmt="plain")
+    assert_equal(result, expected)
